backport stable
authorSylvain Thénault <sylvain.thenault@logilab.fr>
Thu, 16 Feb 2012 14:15:37 +0100
changeset 8239 c6cdd060212e
parent 8237 f854cf9b089e (current diff)
parent 8238 087bb529035c (diff)
child 8240 506ab2e8aeca
backport stable
dbapi.py
hooks/security.py
server/hook.py
server/repository.py
server/sources/ldapuser.py
sobjects/cwxmlparser.py
web/request.py
--- a/dbapi.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/dbapi.py	Thu Feb 16 14:15:37 2012 +0100
@@ -384,7 +384,7 @@
 
     @deprecated('[3.8] use direct access to req.session.data dictionary')
     def session_data(self):
-        """return a dictionnary containing session data"""
+        """return a dictionary containing session data"""
         return self.session.data
 
     @deprecated('[3.8] use direct access to req.session.data dictionary')
@@ -659,9 +659,9 @@
         """return value associated to key in the session's data dictionary or
         session's transaction's data if `txdata` is true.
 
-        If pop is True, value will be removed from the dictionnary.
+        If pop is True, value will be removed from the dictionary.
 
-        If key isn't defined in the dictionnary, value specified by the
+        If key isn't defined in the dictionary, value specified by the
         `default` argument will be returned.
         """
         return self._repo.get_shared_data(self.sessionid, key, default, pop, txdata)
--- a/devtools/fill.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/devtools/fill.py	Thu Feb 16 14:15:37 2012 +0100
@@ -306,7 +306,7 @@
     """generates a random entity and returns it as a dict
 
     by default, generate an entity to be inserted in the repository
-    elif form, generate an form dictionnary to be given to a web controller
+    elif form, generate an form dictionary to be given to a web controller
     """
     eschema = schema.eschema(etype)
     valgen = ValueGenerator(eschema, choice_func)
--- a/hooks/security.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/hooks/security.py	Thu Feb 16 14:15:37 2012 +0100
@@ -31,7 +31,7 @@
     eid = entity.eid
     eschema = entity.e_schema
     # ._cw_skip_security_attributes is there to bypass security for attributes
-    # set by hooks by modifying the entity's dictionnary
+    # set by hooks by modifying the entity's dictionary
     if editedattrs is None:
         editedattrs = entity.cw_edited
     dontcheck = editedattrs.skip_security
--- a/req.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/req.py	Thu Feb 16 14:15:37 2012 +0100
@@ -299,7 +299,7 @@
 
     @cached
     def user_data(self):
-        """returns a dictionnary with this user's information"""
+        """returns a dictionary with this user's information"""
         userinfo = {}
         if self.is_internal_session:
             userinfo['login'] = "cubicweb"
@@ -324,7 +324,7 @@
         object isn't selectable, try to select fallback object if
         `__fallback_oid` is specified.
 
-        If specified `initargs` is expected to be a dictionnary containing
+        If specified `initargs` is expected to be a dictionary containing
         arguments that should be given to selection (hence to object's __init__
         as well), but not to render(). Other arbitrary keyword arguments will be
         given to selection *and* to render(), and so should be handled by
--- a/server/pool.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/pool.py	Thu Feb 16 14:15:37 2012 +0100
@@ -30,7 +30,7 @@
     """
 
     def __init__(self, sources):
-        # dictionnary of (source, connection), indexed by sources'uri
+        # dictionary of (source, connection), indexed by sources'uri
         self.source_cnxs = {}
         for source in sources:
             self.add_source(source)
--- a/server/querier.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/querier.py	Thu Feb 16 14:15:37 2012 +0100
@@ -390,7 +390,7 @@
                 if var.stinfo['constnode'] is not None:
                     eid = var.stinfo['constnode'].eval(self.args)
                     varkwargs[var.name] = typed_eid(eid)
-        # dictionnary of variables restricted for security reason
+        # dictionary of variables restricted for security reason
         localchecks = {}
         restricted_vars = set()
         newsolutions = []
--- a/server/repository.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/repository.py	Thu Feb 16 14:15:37 2012 +0100
@@ -822,9 +822,9 @@
         """return value associated to key in the session's data dictionary or
         session's transaction's data if `txdata` is true.
 
-        If pop is True, value will be removed from the dictionnary.
+        If pop is True, value will be removed from the dictionary.
 
-        If key isn't defined in the dictionnary, value specified by the
+        If key isn't defined in the dictionary, value specified by the
         `default` argument will be returned.
         """
         session = self._get_session(sessionid, setcnxset=False)
--- a/server/sources/ldapuser.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/sources/ldapuser.py	Thu Feb 16 14:15:37 2012 +0100
@@ -177,7 +177,7 @@
 
     def prepare_columns(self, mainvars, rqlst):
         """return two list describing how to build the final results
-        from the result of an ldap search (ie a list of dictionnary)
+        from the result of an ldap search (ie a list of dictionary)
         """
         columns = []
         global_transforms = []
--- a/sobjects/cwxmlparser.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/sobjects/cwxmlparser.py	Thu Feb 16 14:15:37 2012 +0100
@@ -98,11 +98,11 @@
     Most of the logic is delegated to the following components:
 
     * an "item builder" component, turning an etree xml node into a specific
-      python dictionnary representing an entity
+      python dictionary representing an entity
 
     * "action" components, selected given an entity, a relation and its role in
       the relation, and responsible to link the entity to given related items
-      (eg dictionnary)
+      (eg dictionary)
 
     So the parser is only doing the gluing service and the connection to the
     source.
--- a/web/data/cubicweb.htmlhelpers.js	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/data/cubicweb.htmlhelpers.js	Thu Feb 16 14:15:37 2012 +0100
@@ -64,7 +64,7 @@
 /**
  * .. function:: asURL(props)
  *
- * builds an url from an object (used as a dictionnary)
+ * builds an url from an object (used as a dictionary)
  *
  * >>> asURL({'rql' : "RQL", 'x': [1, 2], 'itemvid' : "oneline"})
  * rql=RQL&vid=list&itemvid=oneline&x=1&x=2
--- a/web/formfields.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/formfields.py	Thu Feb 16 14:15:37 2012 +0100
@@ -618,7 +618,7 @@
         if self.format_field:
             return self.format_field
         # we have to cache generated field since it's use as key in the
-        # context dictionnary
+        # context dictionary
         req = form._cw
         try:
             return req.data[self]
--- a/web/uicfg.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/uicfg.py	Thu Feb 16 14:15:37 2012 +0100
@@ -370,7 +370,7 @@
 autoform_permissions_overrides = RelationTagsSet('autoform_permissions_overrides')
 
 class ReleditTags(NoTargetRelationTagsDict):
-    """Associate to relation a dictionnary to control `reledit` (e.g. edition of
+    """Associate to relation a dictionary to control `reledit` (e.g. edition of
     attributes / relations from within views).
 
     Possible keys and associated values are:
--- a/web/uihelper.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/uihelper.py	Thu Feb 16 14:15:37 2012 +0100
@@ -298,10 +298,10 @@
       being consistent with the schema definition.
 
     :attr:`widgets`
-      a dictionnary mapping attribute names to widget instances.
+      a dictionary mapping attribute names to widget instances.
 
     :attr:`fields`
-      a dictionnary mapping attribute names to field instances.
+      a dictionary mapping attribute names to field instances.
 
     Examples:
 
--- a/web/views/urlrewrite.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/views/urlrewrite.py	Thu Feb 16 14:15:37 2012 +0100
@@ -29,7 +29,7 @@
     return re.compile(pattern+'$', flags)
 
 class metarewriter(type):
-    """auto-extend rules dictionnary"""
+    """auto-extend rules dictionary"""
     def __new__(mcs, name, bases, classdict):
         # collect baseclass' rules
         rules = []
--- a/server/hook.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/hook.py	Thu Feb 16 14:15:37 2012 +0100
@@ -115,10 +115,10 @@
 - `before_add_entity`, `before_update_entity`:
 
   On those events, you can access the modified attributes of the entity using
-  the `entity.cw_edited` dictionnary. The values can be modified and the old
+  the `entity.cw_edited` dictionary. The values can be modified and the old
   values can be retrieved.
 
   If you modify the `entity.cw_edited` dictionnary in the hook, that is before
   the database operations take place, you will avoid the need to process a whole
   new rql query and the underlying backend query (eg usually sql) will contain
   the modified data. For example:
@@ -145,12 +145,12 @@
 - `after_add_entity`, `after_update_entity`
 
   On those events, you can get the list of attributes that were modified using
   the `entity.cw_edited` dictionnary, but you can not modify it or get the old
   value of an attribute.
 
 - `before_delete_entity`, `after_delete_entity`
 
   On those events, the entity has no `cw_edited` dictionnary.
 
 .. note:: `self.entity.set_attributes(age=42)` will set the `age` attribute to
   42. But to do so, it will generate a rql query that will have to be processed,
@@ -115,10 +115,10 @@
   values can be retrieved.
 
-  If you modify the `entity.cw_edited` dictionnary in the hook, that is before
+  If you modify the `entity.cw_edited` dictionary in the hook, that is before
   the database operations take place, you will avoid the need to process a whole
   new rql query and the underlying backend query (eg usually sql) will contain
@@ -145,12 +145,12 @@
 
   On those events, you can get the list of attributes that were modified using
-  the `entity.cw_edited` dictionnary, but you can not modify it or get the old
+  the `entity.cw_edited` dictionary, but you can not modify it or get the old
   value of an attribute.
 
@@ -145,12 +145,12 @@
 - `before_delete_entity`, `after_delete_entity`
 
-  On those events, the entity has no `cw_edited` dictionnary.
+  On those events, the entity has no `cw_edited` dictionary.
 
 .. note:: `self.entity.set_attributes(age=42)` will set the `age` attribute to
--- a/server/sources/rql2sql.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/server/sources/rql2sql.py	Thu Feb 16 14:15:37 2012 +0100
@@ -339,7 +339,7 @@
     * `outer_chains`, list of list of strings. Each list represent a tables
       that have to be outer joined together.
 
     * `outer_tables`, dictionnary used as index of tables used in outer join ::
 
         'table alias': (outertype, [conditions], [chain])
 
@@ -721,7 +721,7 @@
         self.attr_map = attrmap
 
     def generate(self, union, args=None, varmap=None):
         """return SQL queries and a variable dictionnary from a RQL syntax tree
 
         :partrqls: a list of couple (rqlst, solutions)
         :args: optional dictionary with values of substitutions used in the query
@@ -772,11 +772,11 @@
         return '\nUNION ALL\n'.join(sqls)
 
     def select_sql(self, select, needalias=False):
         """return SQL queries and a variable dictionnary from a RQL syntax tree
 
         :select: a selection statement of the syntax tree (`rql.stmts.Select`)
-        :solution: a dictionnary containing variables binding.
-          A solution's dictionnary has variable's names as key and variable's
+        :solution: a dictionary containing variables binding.
+          A solution's dictionary has variable's names as key and variable's
           types as values
         :needwrap: boolean telling if the query will be wrapped in an outer
           query (to deal with aggregat and/or grouping)
@@ -339,7 +339,7 @@
       that have to be outer joined together.
 
-    * `outer_tables`, dictionnary used as index of tables used in outer join ::
+    * `outer_tables`, dictionary used as index of tables used in outer join ::
 
         'table alias': (outertype, [conditions], [chain])
@@ -721,7 +721,7 @@
 
     def generate(self, union, args=None, varmap=None):
-        """return SQL queries and a variable dictionnary from a RQL syntax tree
+        """return SQL queries and a variable dictionary from a RQL syntax tree
 
         :partrqls: a list of couple (rqlst, solutions)
@@ -772,11 +772,11 @@
 
     def select_sql(self, select, needalias=False):
-        """return SQL queries and a variable dictionnary from a RQL syntax tree
+        """return SQL queries and a variable dictionary from a RQL syntax tree
 
         :select: a selection statement of the syntax tree (`rql.stmts.Select`)
--- a/web/request.py	Tue Feb 14 09:39:44 2012 +0100
+++ b/web/request.py	Thu Feb 16 14:15:37 2012 +0100
@@ -63,7 +63,7 @@
     * if the parameter is already a list or tuple, just skip internal
       markers
 
-    if pop is True, the parameter is removed from the form dictionnary
+    if pop is True, the parameter is removed from the form dictionary
     """
     if pop:
         try:
@@ -97,7 +97,7 @@
         self.html_headers = HTMLHead(self)
         # form parameters
         self.setup_params(form)
         # dictionnary that may be used to store request data that has to be
         # shared among various components used to publish the request (views,
         # controller, application...)
         self.data = {}
@@ -263,7 +263,7 @@
         * if the parameter is already a list or tuple, just skip internal
           markers
 
-        if pop is True, the parameter is removed from the form dictionnary
+        if pop is True, the parameter is removed from the form dictionary
         """
         if form is None:
             form = self.form
@@ -97,7 +97,7 @@
         # form parameters
         self.setup_params(form)
-        # dictionnary that may be used to store request data that has to be
+        # dictionary that may be used to store request data that has to be
         # shared among various components used to publish the request (views,
         # controller, application...)